#include-once

#include <String.au3>
#include <Date.au3>
#include <Crypt.au3>

#AutoIt3Wrapper_Au3Check_Parameters=-q -d -w 1 -w 2 -w 3 -w 4 -w 5 -w 6 -w 7

; #INDEX# =======================================================================================================================
; Title ..........: JPD_String
; AutoIt Version .: v3.3.14.5
; Description ....: Some other functions for string handling
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Language .......:	English
; Dll ............: -
; ===============================================================================================================================

; #CURRENT# =====================================================================================================================
; ------------------------------ Date Convert
; _StringDateConvert
; _StringIsDate
; ------------------------------- String Handling ---
; _StringCount
; _StringFormatBytesSize
; _StringIsEndingWith
; _StringIsStartingWith
; _StringJoinArray
; _StringPadLeft
; _StringPadRight
; _StringRemoveFrenchAccent
; _StringRemoveChars
; _StringStrip
; _StringTitleCaseFrench
; _StringWSClean
; ===============================================================================================================================

; #INTERNAL_USE_ONLY# ===========================================================================================================
; __sStrRegexLiteral
; ===============================================================================================================================

#Region ### String Date Handling ###
; #FUNCTION# ===========================================================================================================
; Name ...........: _StringDateConvert
; Description ....: Convert a date from one format to another
; Syntax .........: _StringDateConvert($sDate, $sFormatIn = "DMY", $sFormatOut = "YMD")
; -
; Parameter(s) ...:
;					$sDate : Date to convert
;					$sFormatIn : Date format(1) of $sDate
;					$sFormatOut : Date format(1) of output
;						(1) Values for Date format :
;							"YMD" : yyyy/mm/dd[ hh:mm[:ss]]
;                       or "MDY" : mm/dd/yyyy[ hh:mm[:ss]]
;						 or "DMY" : dd/mm/yyyy[ hh:mm[:ss]]
; -
; Return value(s) : Success - Converted date
;					Failure - empty string ("")
;							  @error = 1 : invalid $sFormatIn
;   						  @error = 2 : invalid $sFormatOut
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remarks ........: Input and output date are not validated.
;  					You may use _bDateIsValid for that check before or after process
; Example ........: Yes
;========================================================================================================================
Func _StringDateConvert($sDate, $sFormatIn = "DMY", $sFormatOut = "YMD")
	If StringInStr("YMD@DMY@MDY", $sFormatIn) = 0 Then
		SetError(1)
		Return ""
	EndIf
	If StringInStr("YMD@DMY@MDY", $sFormatIn) = 0 Then
		SetError(2)
		Return ""
	EndIf
	If $sFormatIn = $sFormatOut Then
		Return $sDate
	EndIf

	If $sFormatIn = "YMD" Then
		If $sFormatOut = "DMY" Then
			Return StringRegExpReplace($sDate, '^(\d{4})\D?(\d{2})\D?(\d{2})([\d\s:]*)$', '\3/\2/\1\4')
		ElseIf $sFormatOut = "MDY" Then
			Return StringRegExpReplace($sDate, '^(\d{4})\D?(\d{2})\D?(\d{2})([\d\s:]*)$', '\2/\3/\1\4')
		EndIf
	ElseIf $sFormatIn = "DMY" Then
		If $sFormatOut = "YMD" Then
			Return StringRegExpReplace($sDate, '^(\d{2})\D?(\d{2})\D?(\d{4})([\d\s:]*)$', '\3/\2/\1\4')
		ElseIf $sFormatOut = "MDY" Then
			Return StringRegExpReplace($sDate, '^(\d{2})\D?(\d{2})\D?(\d{4})([\d\s:]*)$', '\2/\1/\3\4')
		EndIf
	ElseIf $sFormatIn = "MDY" Then
		If $sFormatOut = "YMD" Then
			Return StringRegExpReplace($sDate, '^(\d{2})\D?(\d{2})\D?(\d{4})([\d\s:]*)$', '\3/\1/\2\4')
		ElseIf $sFormatOut = "DMY" Then
			Return StringRegExpReplace($sDate, '^(\d{2})\D?(\d{2})\D?(\d{4})([\d\s:]*)$', '\2/\1/\3\4')
		EndIf
	EndIf
EndFunc   ;==>_StringDateConvert

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringIsDate
; Description ....: Validate a Date with a specified format
; Syntax .........: _StringIsDate($sDate, $sFormat = "DMY")
; -
; Parameter(s) ...:
;					$sDate : date to evaluate
;					$sFormat : Format of input date :
;                                "MDY" for yyyy/mm/dd[ hh:mm[:ss]]
;							   or "DMY" for dd/mm/yyyy[ hh:mm[:ss]]
; -
; Return value(s) : Success - True: the date is valid, False : date is not valid
;					Failure -
; -
; Versions .......:	1.0.0
; -
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: adapt the date format for _DateIsValid (YMD)
; Example ........: Yes
;========================================================================================================================
Func _StringIsDate($sDate, $sFormat = "DMY")
	Local $sDateToValidate = ""
	If $sFormat <> "YMD" Then
		$sDateToValidate = _StringDateConvert($sDate, $sFormat, "YMD")
	Else
		$sDateToValidate = $sDate
	EndIf
	Return _DateIsValid($sDateToValidate)
EndFunc   ;==>_StringIsDate
#EndRegion ### String Date Handling ###

#Region ### String handling ###
; #FUNCTION# ===========================================================================================================
; Name ...........: _StringCount
; Description ....: Count the number of times a string appears in a text
; Syntax .........: _StringCount($sText, $sString)
; -
; Parameter(s) ...:
;					$sText : text to scan
;					$sString : string we are looking for
; -
; Return value(s) : Success - Number of occurrences (integer)
;					Failure - return 0
;							  @error = 1 : if an error occurs
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/02/
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringCount($sText, $sString)
	Local $iReturn = 0
	Local $sReplace = "#" & $sString & "#"
	StringReplace($sText, $sString, $sReplace)
	If @error Then
		SetError(1)
	Else
		$iReturn = @extended
	EndIf
	Return $iReturn
EndFunc   ;==>_StringCount

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringFormatBytesSize
; Description ....: Formats a files size according to $sFormat & $iDecimal parameters
; Syntax .........: _StringFormatBytesSize($nValue, $sFormat = "MB", $iDecimal = 2)
; -
; Parameter(s) ...:
;					$nValue = The value in "Bytes"
;					$SFormat = Specify the Size format you wish to display, options are:
;								""      - Auto Select based on value entered
;								"TB"    - Display in Terabytes
;								"GB"    - Display in Gigabytes
;								"MB"    - Display in Megabytes [default value]
;								"KB"    - Display in Kilobytes
;								"B"     - Display in Bytes
;					$iDecimal = The number of decimals places to round up converted value
; -
; Return value(s) : Success - Result of the process
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep) based on a developmet of busysignal
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringFormatBytesSize($nValue, $sFormat = "MB", $iDecimal = 2)
	Local $nB, $nKB, $nMB, $nGB, $nTB

	If Not StringIsDigit($nValue) Or Not StringIsDigit($iDecimal) Then
		SetError(1)
		Return "0 Bytes"
	EndIf

	$nB = $nValue
	$nKB = Round($nB / 1024, $iDecimal)
	$nMB = Round($nKB / 1024, $iDecimal)
	$nGB = Round($nMB / 1024, $iDecimal)
	$nTB = Round($nGB / 1024, $iDecimal)

	Select
		Case $sFormat = "" ; Auto Select Format Display Type
			If $nTB > 1 Then
				$nValue = $nGB & " TB"
			ElseIf $nGB > 1 Then
				$nValue = $nGB & " GB"
			ElseIf $nMB > 1 Then
				$nValue = $nMB & " MB"
			ElseIf $nKB > 1 Then
				$nValue = $nKB & " KB"
			Else
				$nValue = $nB & " Bytes"
			EndIf
		Case $sFormat = "TB"
			$nValue = $nTB & " " & $sFormat
		Case $sFormat = "GB"
			$nValue = $nGB & " " & $sFormat
		Case $sFormat = "MB"
			$nValue = $nMB & " " & $sFormat
		Case $sFormat = "KB"
			$nValue = $nKB & " " & $sFormat
		Case Else
			$nValue = $nB & " " & " Bytes"
	EndSelect
	Return $nValue
EndFunc   ;==>_StringFormatBytesSize

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringIsEndingWith
; Description ....:	Check whether or not the given string ends with the specified text
; Syntax .........: _StringIsEndingWith($sInput, $sSearch, $bCaseSensitive = False)
; -
; Parameter(s) ...:
;					$sInput - The string to be searched
;					$sSearch - The text to search for
;					$bCaseSensitive - Specifies whether the search string should be case sensitive.
; -
; Return value(s) : Success - True if ends with the given string, False otherwise (boolean)
;					Failure -Result of the process
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/18
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringIsEndingWith($sInput, $sSearch, $bCaseSensitive = False)
	Local $iSearchLen = StringLen($sSearch)
	Local $iInputLen = StringLen($sInput)

	If $iSearchLen * $iInputLen = 0 Then Return False
	If ($iSearchLen > $iInputLen) Then Return False

	Local $sInputSearch = StringRight($sInput, $iSearchLen)
	If ($bCaseSensitive) Then
		Return ($sInputSearch == $sSearch)
	Else
		Return ($sInputSearch = $sSearch)
	EndIf

	Return False
EndFunc   ;==>_StringIsEndingWith

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringIsStartingWith
; Description ....:	Check whether or not the given string begins with the specified text.
; Syntax .........: _StringIsStartingWith($sInput, $sSearch, $bCaseSensitive = False)
; -
; Parameter(s) ...:
;					$sInput - The string to be searched
;					$sSearch - The text to search for
;					$bCaseSensitive - Specifies whether the search string should be case sensitive.
; -
; Return value(s) : Success	- True Begin with the given string, otherwise False (boolean)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/18
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringIsStartingWith($sInput, $sSearch, $bCaseSensitive = False)
	Local $iSearchLen = StringLen($sSearch)
	Local $iInputLen = StringLen($sInput)

	If $iSearchLen * $iInputLen = 0 Then Return False ; one empty string
	If ($iSearchLen > $iInputLen) Then Return False ; Search item longer

	Local $sInputSearch = StringLeft($sInput, $iSearchLen)
	If ($bCaseSensitive) Then
		Return ($sInputSearch == $sSearch)
	Else
		Return ($sInputSearch = $sSearch)
	EndIf

	Return False
EndFunc   ;==>_StringIsStartingWith

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringJoinArray
; Description ....: Rebuilds a string based on an array returned by StringSplit
; Syntax .........: _StringJoinArray($asSplitArray, $sDelim = "|")
; -
; Parameter(s) ...:
;					$asSplitArray - The array returned by SplitString(or similar)
;				   	$sDelim - The delimiter to use between Items of $asSplitArray
;
; Return value(s) : Success - Result of the process (string)
;					Failure - empty string ""
;							  @error = 1 : invalid input array
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/25
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringJoinArray($asSplitArray, $sDelim = "|")
	Local $sReturn = ""

	If Not IsArray($asSplitArray) Then
		SetError(1)
		Return $sReturn
	EndIf

	Local $iArrayLen = UBound($asSplitArray) - 1, $iLenDelim = StringLen($sDelim)
	For $i = 1 To $iArrayLen
		$sReturn &= $asSplitArray[$i] & $sDelim
	Next

	If ($iLenDelim > 0) Then $sReturn = StringTrimRight($sReturn, $iLenDelim)

	Return $sReturn
EndFunc   ;==>_StringJoinArray

; #FUNCTION# ===========================================================================================================
; Name ............: _StringPadLeft
; Description .....:	Pads the specified string on the left side, to give it a specific length
; Syntax  .........: _StringPadLeft($sInput, $sPadChar, $iTotalLength, $bTruncate = False)
; -
; Parameter(s) ....:
;					$sInput - The string to be padded
;					$vPadChar - The padding character
;					$iTotalLength - The new length of the string
;					$bTruncate - 	True : truncate $sInput if is Len > $iTotalLength
;									False : unaltered $sInput
; -
; Return value(s) : Success - result of the process (string)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringPadLeft($sInput, $sPadChar, $iTotalLength, $bTruncate = False)
	Local $sReturn = $sInput
	If $bTruncate And (StringLen($sReturn) > $iTotalLength) Then
		$sReturn = StringLeft($sReturn, $iTotalLength)
	Else
		$sReturn = _StringRepeat($sPadChar, $iTotalLength - StringLen($sInput)) & $sReturn
	EndIf
	SetError(0)
	Return $sReturn
EndFunc   ;==>_StringPadLeft

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringPadLeftInteger
; Description ....: Return a string of a given len compose of an intger pad on left with a specific character
; Syntax .........: _StringPadLeftInteger($iInt, $iLen, $sPadChar = "0", $bTruncate = False)
; -
; Parameter(s) ...:
;					$iInt : integer to put at the end of the string
;					$iLen : len of the resulting string
;					$sPadChar : character to repeat on the left side, truncate to 1 character if len > 1.
;					$bTruncate - True : truncate Input if is Len > $iLen
;								 False : unaltered $sInput
;
; Return value(s) : Success - Result of the process (string)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: if string representation of $iInt is too long the result is not truncated
; Example ........: Yes
;========================================================================================================================
Func _StringPadLeftInteger($iInt, $iLen, $sPadChar = "0", $bTruncate = False)
	Local $sResult = String($iInt)
	Return _StringPadLeft($sResult, $sPadChar, $iLen, $bTruncate)
EndFunc   ;==>_StringPadLeftInteger

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringPadRight
; Description ....:	Pads the specified string on the right side, to give it a specific length.
; Syntax .........: _StringPadRight($sInput, $sPadChar, $iTotalLength, $bTruncate = False)
; -
; Parameter(s) ...:
;					$sInput - The string to be padded
;					$sPadChar - The padding character
;					$iTotalLength - The new length of the string
;					$bTruncate : True : If $sInput is too long he will be truncated to $iTotalLength and no pad
; -
; Return value(s) : Success - The result of the process
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringPadRight($sInput, $sPadChar, $iTotalLength, $bTruncate = False)
	Local $sReturn = $sInput
	If $bTruncate And (StringLen($sReturn) > $iTotalLength) Then
		$sReturn = StringLeft($sReturn, $iTotalLength)
	Else
		$sReturn &= _StringRepeat($sPadChar, $iTotalLength - StringLen($sInput))
	EndIf
	Return $sReturn
EndFunc   ;==>_StringPadRight

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringRemoveFrenchAccent
; Description ....: Convert characters with accent to a fom without accent based on french language
; Syntax .........: _StringRemoveFrenchAccent($sString)
; -
; Parameter(s) ...:
;					$sString to convert
; -
; Return value(s) : Success - Result of the process (String)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/01
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringRemoveFrenchAccent($sString)
	Local $sFrom = "àáâãäåæçèéêëìíîïòóôöùúûüýÿœ", $sChar = "", $sOutString = ""
	Local $aTo = ["a", "a", "a", "a", "a", "a", "ae", "c", "e", "e", "e", "e", "i", "i", "i", "i", "o", "o", "o", "o", _
			"u", "u", "u", "u", "y", "y", "oe"]
	Local $aChars = StringSplit($sString, "")
	Local $iPos = 0

	For $i = 1 To $aChars[0]
		$sChar = $aChars[$i]
		$iPos = StringInStr($sFrom, $sChar)
		If $iPos = 0 Then
			$sOutString &= $sChar
		Else
			If StringIsUpper($sChar) Then
				$sOutString &= StringUpper($aTo[$iPos])
			Else
				$sOutString &= $aTo[$iPos]
			EndIf
		EndIf
	Next
	Return $sOutString
EndFunc   ;==>_StringRemoveFrenchAccent

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringRemoveChars
; Description ....:	Removes a specified number of characters from the given string
; Syntax .........: _StringRemoveChars($sInput, $iStart, $iCount)
; -
; Parameter(s) ...:
;					Input - The string to searched
;					$iStart - The starting position of the string to be removed
;					$iCount - The number of characters to remove, starting at $iStart.
; -
; Return value(s) : Success - The result of the process (string)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringRemoveChars($sInput, $iStart, $iCount)
	Local $sResult = ""
	If $iStart < 1 Then $iStart = 1

	$sResult = StringMid($sInput, 1, $iStart - 1)
	$sResult &= StringMid($sInput, $iStart + $iCount)

	Return $sResult
EndFunc   ;==>_StringRemoveChars

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringStrip
; Description ....: Delete Leading or Trailing occurrences of a specified Substring $sSearch from a given text
; Syntax .........: _StringStrip($sText, $sSearch, $iMode = 2, $bAll = False)
; -
; Parameter(s) ...:
;					$sText : Text to clean
;					$sSearch : String to remove
;       			$bAll : True - all occurences are remove
;		        			False - Only one occurence will be remove
;					$iMode
;							1 = strip leading $sSearch
; 							2 = strip trailing $sSearch
; 							3 = strip Leading and Trailing $sSearch
; -
; Return value(s) : Success	- Result of the process (string)
;					Failure - empty string
;                            @error=1 : $iMode is not an integer
;                            #error=2 : $iMode is unknown, not 1, 2 or 3
; -
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/15
; Modified .......: -
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func _StringStrip($sText, $sSearch, $iMode = 2, $bAll = False)
	If Not StringIsInt($iMode) Then
		SetError(1)
		Return ""
	EndIf
	If $iMode < 1 Or $iMode > 3 Then
		SetError(2)
		Return ""
	EndIf

	Local $sExp = ""

	If $iMode = 2 Or $iMode = 3 Then
		$sExp = "(" & __StringRegexLiteral($sSearch) & ")"
		If $bAll Then $sExp &= "+"
		$sExp &= "$"
		$sText = StringRegExpReplace($sText, $sExp, "")
	EndIf

	If $iMode = 1 Or $iMode = 3 Then
		$sExp = "^(" & __StringRegexLiteral($sSearch) & ")"
		If $bAll Then $sExp &= "+"
		$sText = StringRegExpReplace($sText, $sExp, "")
	EndIf

	Return $sText
EndFunc   ;==>_StringStrip

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringTitleCaseFrench
; Description ....: Uppercase first letter of each word + support a French context
;					No uppercase after "'"
; Syntax .........: _StringTitleCaseFrench($sString, $sLanguage = "FR")
; -
; Parameter(s) ...:
;					$sString - string of characters to convert
;					$sLanguage = "FR" like French to process accent characters; They are removed before converting to
;                               uppercase
; -
; Return value(s) : Success	- result of the process
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/01/01
; Modified .......: -
; Remarks ........: -
; Example ........: Yes
;========================================================================================================================
Func _StringTitleCaseFrench($sString, $sLanguage = "FR")
	Local $bCapNext = True
	Local $sChr = "", $sReturn = ""
	Local $aChars = StringSplit($sString, "")

	For $i = 1 To $aChars[0]
		$sChr = $aChars[$i]
		Select
			Case $bCapNext = True
				If StringRegExp($sChr, "[a-zA-Z\xC0-\xFF0-9]") Then
					If $sLanguage = "FR" Then $sChr = (_StringRemoveFrenchAccent($sChr))
					$sChr = StringUpper($sChr)
					$bCapNext = False
				EndIf
			Case ($sLanguage <> "FR" And Not StringRegExp($sChr, "[a-zA-Z\xC0-\xFF'0-9]")) Or _
					(Not StringRegExp($sChr, "(*UCP)[a-zA-Z\xC0-\xFF0-9'’]"))
				$bCapNext = True
			Case Else
				$sChr = StringLower($sChr)
		EndSelect
		$sReturn &= $sChr
	Next
	Return $sReturn
EndFunc   ;==>_StringTitleCaseFrench

; #FUNCTION# ===========================================================================================================
; Name ...........: _StringWSClean
; Description ....: Convert white spaces to spaces, then removes multiples spaces and Leading and trailing
;					spaces from a text
; Syntax .........: _StringWSClean($sText)
; -
; Parameter(s) ...:
;					$sText : Text to clean
; -
; Return value(s) : Success - Result of the process
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep) with thanks of Jchd
; Date ...........: 2019/01/28
; Modified .......: -
; Remark(s) ......: White spaces are replaced by space(" ")
; Example ........: Yes
;========================================================================================================================
Func _StringWSClean($sText)
	$sText = StringRegExpReplace($sText, "[[:space:]]+", " ")
	Return StringStripWS($sText, $STR_STRIPLEADING + $STR_STRIPTRAILING)
EndFunc   ;==>_StringWSClean
; #### Internal use ###

; #FUNCTION# ===========================================================================================================
; Name ...........: __StringRegexLiteral
; Description ....: Prefix each character with "\" in a text for use as literal with RegEx
; Syntax .........: __StringRegexLiteral($sText)
; -
; Parameter(s) ...:
;					$sText : string of character to convert
; -
; Return value(s) : Success - Result of the process (string)
;					Failure -
; -
; Versions .......: 1.0.0
; Author(s) ......: Jean-Pol Dekimpe (Jeep)
; Date ...........: 2019/02/15
; Remark(s) ......: -
; Example ........: Yes
;========================================================================================================================
Func __StringRegexLiteral($sText)
	Local $sResult = ""
	Local $iLen = StringLen($sText)
	For $i = 1 To $iLen
		$sResult &= "\" & StringMid($sText, $i, 1)
	Next
	Return $sResult
EndFunc   ;==>__StringRegexLiteral
